summaryrefslogtreecommitdiff
path: root/lib/zlib/contrib/minizip/zip.c
diff options
context:
space:
mode:
Diffstat (limited to 'lib/zlib/contrib/minizip/zip.c')
-rw-r--r--lib/zlib/contrib/minizip/zip.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/zlib/contrib/minizip/zip.c b/lib/zlib/contrib/minizip/zip.c
index 7fbe002743..bb678ee133 100644
--- a/lib/zlib/contrib/minizip/zip.c
+++ b/lib/zlib/contrib/minizip/zip.c
@@ -99,7 +99,7 @@ typedef struct linkedlist_datablock_internal_s
struct linkedlist_datablock_internal_s* next_datablock;
uLong avail_in_this_block;
uLong filled_in_this_block;
- uLong unused; /* for future use and alignement */
+ uLong unused; /* for future use and alignment */
unsigned char data[SIZEDATA_INDATABLOCK];
} linkedlist_datablock_internal;
@@ -117,12 +117,12 @@ typedef struct
uInt pos_in_buffered_data; /* last written byte in buffered_data */
uLong pos_local_header; /* offset of the local header of the file
- currenty writing */
+ currently writing */
char* central_header; /* central header data for the current file */
uLong size_centralheader; /* size of the central header for cur file */
uLong flag; /* flag of the file currently writing */
- int method; /* compression method of file currenty wr.*/
+ int method; /* compression method of file currently wr.*/
int raw; /* 1 for directly writing raw data */
Byte buffered_data[Z_BUFSIZE];/* buffer contain compressed data to be writ*/
uLong dosDate;